@@ -6,8 +6,14 @@ from cloudrail.knowledge.context.aws.cloudformation.cloudformation_utils import
 from cloudrail.knowledge.context.aws.resources.cloudformation.cloudformation_resource_info import CloudformationResourceInfo
 from cloudrail.knowledge.context.aws.resources.cloudformation.cloudformation_resource_status import CloudformationResourceStatus
 from cloudrail.knowledge.context.aws.resources.ec2.security_group import SecurityGroup
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.dms.cloudformation_dms_replication_instance_builder import CloudformationDmsReplicationInstanceBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.iam.cloudformation_iam_instance_profile_builder import CloudformationIamInstanceProfileBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.docdb.cloudformation_docdb_cluster_builder import CloudformationDocumentDbClusterBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.docdb.cloudformation_docdb_cluster_parameter_group_builder import CloudformationDocDbClusterParameterGroupBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.kms.cloudformation_kms_key_policy_builder import CloudformationKmsKeyPolicyBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.nat_gw.cloudformation_nat_gw_builder import CloudformationNatGatewayBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.dynamodb.cloudformation_dynamodb_table_builder import CloudformationDynamoDbTableBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.codebuild.cloudformation_codebuild_project_builder import CloudformationCodeBuildProjectBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.configservice.cloudformation_config_service_aggregator_builder import CloudformationConfigServiceAggregatorBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.ec2.cloudformation_network_acl_builder import \
     CloudformationNetworkAclAssociationBuilder, CloudformationNetworkAclBuilder, NetworkAclRuleBuilder
@@ -17,6 +23,14 @@ from cloudrail.knowledge.context.aws.resources_builders.cloudformation.iam.cloud
     CloudformationAssumeRolePolicyBuilder, CloudformationInlineRolePolicyBuilder, CloudformationS3BucketPolicyBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.lambda_function.cloudformation_lambda_function_builder import \
     CloudformationLambdaFunctionBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.s3_bucket.cloudformation_public_access_block_settings_builder import \
+    CloudformationPublicAccessBlockSettingsBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.vpc_gateway.cloudformation_transit_gateway_attachment_builder import \
+    CloudformationTransitGatewayAttachmentBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.vpc_gateway.cloudformation_transit_gateway_builder import \
+    CloudformationTransitGatewayBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.vpc_gateway.cloudformation_transit_gateway_route_table_builder import \
+    CloudformationTransitGatewayRouteTableBuilder, CloudformationTransitGatewayRouteTableAssociationBuilder, CloudformationTransitGatewayRouteBuilder
 from cloudrail.knowledge.context.base_environment_context import BaseEnvironmentContext
 from cloudrail.knowledge.context.aws.cloudformation.cloudformation_constants import CloudformationResourceType
 from cloudrail.knowledge.context.aws.cloudformation.cloudformation_metadata_parser import CloudformationMetadataParser
@@ -29,6 +43,7 @@ from cloudrail.knowledge.context.aws.resources_builders.cloudformation.api_gatew
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.athena.cloudformation_athena_workgroup_builder import \
     CloudformationAthenaWorkgroupBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.kms.cloudformation_kms_key_builder import CloudformationKmsKeyBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.kms.cloudformation_kms_alias_builder import CloudformationKmsAliasBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.batch.cloudformation_batch_compute_environment_builder import \
     CloudformationBatchComputeEnvironmentBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.cloudtrail.cloudfromation_cloudtrail_builder import \
@@ -60,6 +75,8 @@ from cloudrail.knowledge.context.aws.resources_builders.cloudformation.ec2.cloud
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.ec2.cloudformation_subnet_builder import CloudformationSubnetBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.ec2.cloudformation_subnet_route_table_association_builder import \
     CloudformationSubnetRouteTableAssociationBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.cloudfront.cloudformation_cloudfront_origin_access_identity_builder import \
+    CloudformationCloudfrontOriginAccessIdentityBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.ec2.cloudformation_vpc_builder import CloudformationVpcBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.ec2.cloudformation_vpc_gateway_attachment_builder import \
     CloudformationVpcGatewayAttachmentBuilder
@@ -74,12 +91,15 @@ from cloudrail.knowledge.context.aws.resources_builders.cloudformation.load_bala
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.load_balancer.cloudformation_load_balancer_target_group_builder import \
     CloudformationLoadBalancerTargetGroupBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.s3_bucket.cloudformation_s3_bucket_builder import \
-    CloudformationS3BucketBuilder, \
-    CloudformationS3BucketEncryptionBuilder, CloudformationS3BucketVersioningBuilder, CloudformationS3BucketLoggingBuilder
+    CloudformationS3BucketBuilder, CloudformationS3BucketEncryptionBuilder, CloudformationS3BucketVersioningBuilder, \
+        CloudformationS3BucketLoggingBuilder, CloudformationS3BucketAclBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.autoscaling.cloudformation_auto_scaling_group_builder import CloudformationAutoScalingGroupBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.autoscaling.cloudformation_launch_configuration_builder import CloudformationLaunchConfigurationBuilder
 from cloudrail.knowledge.context.aws.resources_builders.cloudformation.autoscaling.cloudformation_launch_template_builder import CloudformationLaunchTemplateBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.kinesis.cloudformation_kinesis_stream_builder import CloudformationKinesisStreamBuilder
+from cloudrail.knowledge.context.aws.resources_builders.cloudformation.dax.cloudformation_dax_cluster_builder import CloudformationDaxClusterBuilder
 from cloudrail.knowledge.context.environment_context.iac_context_builder import IacContextBuilder
+from cloudrail.knowledge.context.aws.aws_relations_assigner import AwsRelationsAssigner
 
 
 class AwsCloudformationContextBuilder(IacContextBuilder):
@@ -90,6 +110,8 @@ class AwsCloudformationContextBuilder(IacContextBuilder):
               scanner_environment_context: Optional[BaseEnvironmentContext] = None,
               salt: Optional[str] = None,
               **extra_args) -> AwsEnvironmentContext:
+        if not iac_file:
+            return AwsEnvironmentContext()
         template_content: dict = CloudformationUtils.load_cfn_template(iac_file)
         iac_url_template: Optional[str] = extra_args.get('iac_url_template')
         extra_params: dict = template_content.get(CloudformationUtils.EXTRA_PARAMETERS_KEY, {})
@@ -100,6 +122,8 @@ class AwsCloudformationContextBuilder(IacContextBuilder):
             raise Exception('missing \'region\' parameter')
 
         if scanner_environment_context:
+            AwsRelationsAssigner(scanner_environment_context).run()
+            scanner_environment_context.clear_cache()
             if account := scanner_environment_context.accounts.get(account_id):
                 if not account_id:
                     account_id = account.account
@@ -138,6 +162,7 @@ class AwsCloudformationContextBuilder(IacContextBuilder):
             kms_keys=CloudformationKmsKeyBuilder(cfn_by_type_map).build(),
             security_groups=AliasesDict(*security_groups),
             security_group_rules=security_groups_rules,
+            dms_replication_instance_subnet_groups=CloudformationDmsReplicationInstanceBuilder(cfn_by_type_map).build(),
             internet_gateways=CloudformationInternetGatewayBuilder(cfn_by_type_map).build(),
             vpc_gateway_attachment=AliasesDict(*CloudformationVpcGatewayAttachmentBuilder(cfn_by_type_map).build()),
             subnets=AliasesDict(*CloudformationSubnetBuilder(cfn_by_type_map).build()),
@@ -174,7 +199,23 @@ class AwsCloudformationContextBuilder(IacContextBuilder):
             lambda_function_list=CloudformationLambdaFunctionBuilder(cfn_by_type_map).build(),
             network_acls=AliasesDict(*CloudformationNetworkAclBuilder(cfn_by_type_map).build()),
             network_acl_associations=AliasesDict(*CloudformationNetworkAclAssociationBuilder(cfn_by_type_map).build()),
-            network_acl_rules=NetworkAclRuleBuilder(cfn_by_type_map).build()
+            network_acl_rules=NetworkAclRuleBuilder(cfn_by_type_map).build(),
+            dax_cluster=CloudformationDaxClusterBuilder(cfn_by_type_map).build(),
+            s3_public_access_block_settings_list=CloudformationPublicAccessBlockSettingsBuilder(cfn_by_type_map).build(),
+            iam_instance_profiles=CloudformationIamInstanceProfileBuilder(cfn_by_type_map).build(),
+            transit_gateway_attachments=CloudformationTransitGatewayAttachmentBuilder(cfn_by_type_map).build(),
+            transit_gateways=CloudformationTransitGatewayBuilder(cfn_by_type_map).build(),
+            transit_gateway_route_tables=CloudformationTransitGatewayRouteTableBuilder(cfn_by_type_map).build(),
+            transit_gateway_route_table_associations=CloudformationTransitGatewayRouteTableAssociationBuilder(cfn_by_type_map).build(),
+            transit_gateway_routes=CloudformationTransitGatewayRouteBuilder(cfn_by_type_map).build(),
+            codebuild_projects=CloudformationCodeBuildProjectBuilder(cfn_by_type_map).build(),
+            docdb_cluster=CloudformationDocumentDbClusterBuilder(cfn_by_type_map).build(),
+            docdb_cluster_parameter_groups=CloudformationDocDbClusterParameterGroupBuilder(cfn_by_type_map).build(),
+            kms_aliases=CloudformationKmsAliasBuilder(cfn_by_type_map).build(),
+            kms_keys_policies=CloudformationKmsKeyPolicyBuilder(cfn_by_type_map).build(),
+            kinesis_streams=CloudformationKinesisStreamBuilder(cfn_by_type_map).build(),
+            origin_access_identity_list=CloudformationCloudfrontOriginAccessIdentityBuilder(cfn_by_type_map).build(),
+            s3_bucket_acls=CloudformationS3BucketAclBuilder(cfn_by_type_map).build(),
         )
 
     @staticmethod
