@@ -44,4 +44,4 @@ class Account(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, }
+        return {}
