@@ -2,6 +2,7 @@ from typing import List, Optional
 
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class ApiGatewayVpcLink(AwsResource):
@@ -62,6 +63,6 @@ class ApiGatewayVpcLink(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'name': self.name,
+        return {'tags': filter_tags(self.tags), 'name': self.name,
                 'security_group_ids': self.security_group_ids,
                 'subnet_ids': self.subnet_ids}
