@@ -1,6 +1,7 @@
 from typing import List
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class CloudTrail(AwsResource):
@@ -56,7 +57,8 @@ class CloudTrail(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'name': self.name,
+        return {'tags': filter_tags(self.tags),
+                'name': self.name,
                 'kms_encryption': self.kms_encryption,
                 'log_file_validation': self.log_file_validation,
                 'is_multi_region_trail': self.is_multi_region_trail}
