@@ -43,4 +43,4 @@ class CloudWatchLogsDestination(PoliciedResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'name': self.name}
+        return {'name': self.name}
