@@ -3,6 +3,7 @@ from typing import List, Optional
 from cloudrail.knowledge.context.aws.resources.kms.kms_key import KmsKey
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class DocumentDbCluster(AwsResource):
@@ -59,7 +60,7 @@ class DocumentDbCluster(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'storage_encrypted': self.storage_encrypted,
-                'parameter_group_name': self.parameter_group_name,
+        return {'tags': filter_tags(self.tags),
+                'storage_encrypted': self.storage_encrypted,
                 'kms_key_id': self.kms_key_id,
                 'enabled_cloudwatch_logs_exports': self.enabled_cloudwatch_logs_exports}
