@@ -6,6 +6,7 @@ from typing import List, Optional
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
 from cloudrail.knowledge.context.aws.resources.docdb.docdb_cluster_parameter import DocDbClusterParameter
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 @dataclass
@@ -63,4 +64,5 @@ class DocDbClusterParameterGroup(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'group_name': self.group_name}
+        return {'tags': filter_tags(self.tags),
+                'group_name': self.group_name}
