@@ -48,5 +48,5 @@ class MainRouteTableAssociation(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'vpc_id': self.vpc_id,
+        return {'vpc_id': self.vpc_id,
                 'route_table_id': self.route_table_id}
