@@ -46,7 +46,7 @@ class GlobalAcceleratorEndpointGroup(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'listener_arn': self.listener_arn,
+        return {'listener_arn': self.listener_arn,
                 'endpoint_arn': self.endpoint_arn,
                 'endpoint_config_id': self.endpoint_config_id,
                 'client_ip_preservation_enabled': self.client_ip_preservation_enabled}
