@@ -50,7 +50,7 @@ class GlueConnection(NetworkEntity):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'connection_name': self.connection_name,
+        return {'connection_name': self.connection_name,
                 'assign_public_ip': self.vpc_config and self.vpc_config.assign_public_ip,
                 'security_groups_ids': self.vpc_config and self.vpc_config.security_groups_ids,
                 'subnet_list_ids': self.vpc_config and self.vpc_config.subnet_list_ids}
