@@ -40,4 +40,4 @@ class IamUsersLoginProfile(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'name': self.name}
+        return {'name': self.name}
