@@ -2,6 +2,7 @@ from typing import List
 
 from cloudrail.knowledge.context.aws.resources.service_name import AwsServiceName
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
+from cloudrail.knowledge.utils.tags_utils import filter_tags
 
 
 class KinesisStream(AwsResource):
@@ -32,6 +33,9 @@ class KinesisStream(AwsResource):
     def get_arn(self) -> str:
         return self.stream_arn
 
+    def get_id(self) -> str:
+        return self.stream_name
+
     def get_type(self, is_plural: bool = False) -> str:
         if not is_plural:
             return 'Kinesis Data Stream'
@@ -47,5 +51,5 @@ class KinesisStream(AwsResource):
         return True
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'stream_name': self.stream_name,
+        return {'tags': filter_tags(self.tags), 'stream_name': self.stream_name,
                 'encrypted_at_rest': self.encrypted_at_rest}
