@@ -32,6 +32,9 @@ class KmsAlias(AwsResource):
     def get_name(self) -> str:
         return self.alias_name
 
+    def get_id(self) -> str:
+        return self.alias_name
+
     def get_arn(self) -> str:
         return self.alias_arn
 
@@ -54,5 +57,5 @@ class KmsAlias(AwsResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'alias_name': self.alias_name,
+        return {'alias_name': self.alias_name,
                 'target_key_id': self.target_key_id}
