@@ -36,5 +36,5 @@ class KmsKeyPolicy(ResourceBasedPolicy):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'key_id': self.key_id,
+        return {'key_id': self.key_id,
                 'policy_statements': [statement.to_dict() for statement in self.statements]}
