@@ -63,6 +63,6 @@ class S3BucketAccessPoint(PoliciedResource):
         return False
 
     def to_drift_detection_object(self) -> dict:
-        return {'tags': self.tags, 'bucket_name': self.bucket_name,
+        return {'bucket_name': self.bucket_name,
                 'name': self.name,
                 'network_origin': dataclasses.asdict(self.network_origin)}
