@@ -1,6 +1,10 @@
 from abc import abstractmethod
 from typing import List, Dict, Union, Optional
 from cloudrail.knowledge.context.aws.resources.aws_resource import AwsResource
+from cloudrail.knowledge.context.aws.resources.codebuild.codebuild_project import CodeBuildProject
+from cloudrail.knowledge.context.aws.resources.codebuild.codebuild_report_group import CodeBuildReportGroup
+from cloudrail.knowledge.context.aws.resources.dynamodb.dynamodb_table import DynamoDbTable
+from cloudrail.knowledge.context.aws.resources.docdb.docdb_cluster import DocumentDbCluster
 from cloudrail.knowledge.context.iac_resource_metadata import IacResourceMetadata
 from cloudrail.knowledge.context.iac_state import IacState
 from cloudrail.knowledge.context.iac_action_type import IacActionType
@@ -10,11 +14,13 @@ from cloudrail.knowledge.context.aws.cloudformation.intrinsic_functions.cloudfor
 from cloudrail.knowledge.context.iac_type import IacType
 from cloudrail.knowledge.utils.string_utils import generate_random_string
 from cloudrail.knowledge.utils.tags_utils import get_aws_tags
+from cloudrail.knowledge.utils.arn_utils import is_valid_arn, build_arn
 
 
 class BaseCloudformationBuilder:
 
     CFN_PSEUDO_PREFIX: str = 'cfn-pseudo'
+    CFN_PSEUDO_LIST: list = ['cfn-pseudo']
 
     def __init__(self, cfn_resource_type: CloudformationResourceType, cfn_by_type_map: Dict[CloudformationResourceType, Dict[str, Dict]]) -> None:
         super().__init__()
@@ -23,14 +29,15 @@ class BaseCloudformationBuilder:
     def build(self) -> list:
         aws_resources_list: List[AwsResource] = []
         for cfn_resource in self._resources.values():
-            if 'Properties' not in cfn_resource:
-                cfn_resource['Properties'] = {}
+            if cfn_resource['iac_action'] != IacActionType.DELETE:
+                if 'Properties' not in cfn_resource:
+                    cfn_resource['Properties'] = {}
 
-            build_result = self.parse_resource(cfn_resource)
-            for aws_resource in build_result if isinstance(build_result, list) else [build_result]:
-                if aws_resource:
-                    self._set_common_attributes(aws_resource, cfn_resource)
-                    aws_resources_list.append(aws_resource)
+                build_result = self.parse_resource(cfn_resource)
+                for aws_resource in build_result if isinstance(build_result, list) else [build_result]:
+                    if aws_resource:
+                        self._set_common_attributes(aws_resource, cfn_resource)
+                        aws_resources_list.append(aws_resource)
         return aws_resources_list
 
     @abstractmethod
@@ -53,6 +60,18 @@ class BaseCloudformationBuilder:
         else:
             return prop_value
 
+    @staticmethod
+    def get_encryption_key_arn(encryption_key: Optional[str], account: str, region: str, resource: object) -> Optional[str]:
+        if encryption_key and not is_valid_arn(encryption_key) and not 'alias' in encryption_key:
+            encryption_key = build_arn('kms', region, account,'key', None, encryption_key)
+        if (resource in (CodeBuildProject, CodeBuildReportGroup) and not encryption_key) or encryption_key == 'alias/aws/s3':
+            encryption_key = build_arn('kms', region, account,'alias', None, 'aws/s3')
+        if resource == DynamoDbTable and not encryption_key:
+            encryption_key = 'alias/aws/dynamodb'
+        if resource == DocumentDbCluster and not encryption_key:
+            encryption_key = 'alias/aws/rds'
+        return encryption_key
+
     @classmethod
     def get_name_tag(cls, properties: dict) -> str:
         return cls.get_tag(properties, 'Name')
