@@ -5,6 +5,8 @@ from cloudrail.knowledge.rules.gcp.non_context_aware.sql_database_instance_no_pu
     SqlDatabaseNoPublicIpRule
 from cloudrail.knowledge.rules.gcp.non_context_aware.sql_database_ssl_required_rule import SqlDatabaseSslRequiredRule
 from cloudrail.knowledge.rules.gcp.non_context_aware.sql_restrict_trusted_ip_rule import SqlDatabaseRestrictTrustedIpRule
+from cloudrail.knowledge.rules.gcp.non_context_aware.compute_instance_no_serial_port_connection_rule import ComputeInstanceNoSerialPortConnectionRule
+from cloudrail.knowledge.rules.gcp.non_context_aware.compute_instance_launch_with_vm_shield_rule import ComputeInstanceLaunchWithVmShieldRule
 from cloudrail.knowledge.rules.abstract_rules_loader import AbstractRulesLoader
 
 
@@ -14,6 +16,8 @@ class GcpRulesLoader(AbstractRulesLoader):
         rules: List[BaseRule] = [
             SqlDatabaseSslRequiredRule(),
             SqlDatabaseRestrictTrustedIpRule(),
-            SqlDatabaseNoPublicIpRule()
+            SqlDatabaseNoPublicIpRule(),
+            ComputeInstanceNoSerialPortConnectionRule(),
+            ComputeInstanceLaunchWithVmShieldRule(),
         ]
         return {rule.get_id(): rule for rule in rules}
