@@ -7,7 +7,7 @@ import random
 import uuid
 from functools import reduce
 from multiprocessing.pool import Pool
-from typing import List, Callable, Iterator, Optional, Tuple
+from typing import Iterable, List, Callable, Iterator, Optional, Tuple
 from pathlib import Path
 
 from netaddr import IPNetwork, IPSet, AddrFormatError, valid_ipv4, valid_ipv6
@@ -137,6 +137,8 @@ def flat_list(list_of_lists: List[list]) -> list:
 def hash_list(data: list) -> int:
     return hash(str(data))
 
+def is_iterable_with_values(iterable: Iterable) -> bool:
+    return any(x is not None for x in iterable)
 
 # --- NETWORKING UTILS
 def compare_prefix_length(cidr1: str, cidr2: str) -> int:
